@@ -17,8 +17,8 @@ package Dist::Zilla::Plugin::PodLoom;
 # ABSTRACT: Process module documentation through Pod::Loom
 #---------------------------------------------------------------------
 
-our $VERSION = '3.02';
-# This file is part of Dist-Zilla-Plugin-PodLoom 3.02 (December 11, 2010)
+our $VERSION = '4.00';
+# This file is part of Dist-Zilla-Plugin-PodLoom 4.00 (May 5, 2011)
 
 
 use Moose;
@@ -90,7 +90,7 @@ sub munge_file
 
   my $info = $self->get_module_info($file);
 
-  my $abstract = Dist::Zilla::Util->abstract_from_file($file->name);
+  my $abstract = Dist::Zilla::Util->abstract_from_file($file);
   my $repo     = $self->zilla->distmeta->{resources}{repository};
 
   my $dataHash = Hash::Merge::Simple::merge(
@@ -137,9 +137,9 @@ Dist::Zilla::Plugin::PodLoom - Process module documentation through Pod::Loom
 
 =head1 VERSION
 
-This document describes version 3.02 of
-Dist::Zilla::Plugin::PodLoom, released December 11, 2010
-as part of Dist-Zilla-Plugin-PodLoom version 3.02.
+This document describes version 4.00 of
+Dist::Zilla::Plugin::PodLoom, released May 5, 2011
+as part of Dist-Zilla-Plugin-PodLoom version 4.00.
 
 =head1 SYNOPSIS
 
@@ -237,7 +237,7 @@ L<< http://github.com/madsen/dist-zilla-plugin-podloom >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Christopher J. Madsen.
+This software is copyright (c) 2011 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
